@@ -4,7 +4,7 @@ import glob
 import logging
 import os
 from pathlib import Path
-import pkg_resources
+from packaging import version
 import re
 import shutil
 import shlex
@@ -439,7 +439,8 @@ def prepare(tool, branch, user, included):
                 else:
                     msg += _("please go to {} in your web browser and try again.").format(AUTH_URL)
 
-                msg += _((" For instructions on how to set up a personal access token, please visit https://cs50.ly/github"))
+                if not os.environ.get("CODESPACES"):
+                    msg += _((" For instructions on how to set up a personal access token, please visit https://cs50.readthedocs.io/github"))
 
                 raise Error(msg)
 
@@ -459,8 +460,9 @@ def prepare(tool, branch, user, included):
             # Switch to branch without checkout
             run(git("symbolic-ref HEAD {ref}", ref=f"refs/heads/{branch}"))
 
-            # Git add all included files
-            run(git(f"add -f {' '.join(shlex.quote(f) for f in included)}"))
+            # Git add all included files individually to handle files with special characters
+            for file in included:
+                run(git("add -f -- {file}", file=file))
 
             # Remove gitattributes from included
             if Path(".gitattributes").exists() and ".gitattributes" in included:
@@ -660,9 +662,9 @@ def check_dependencies():
         raise Error(_("You don't have git. Install git, then re-run!"))
 
     # Check that git --version > 2.7
-    version = subprocess.check_output(["git", "--version"]).decode("utf-8")
-    matches = re.search(r"^git version (\d+\.\d+\.\d+).*$", version)
-    if not matches or pkg_resources.parse_version(matches.group(1)) < pkg_resources.parse_version("2.7.0"):
+    _version = subprocess.check_output(["git", "--version"]).decode("utf-8")
+    matches = re.search(r"^git version (\d+\.\d+\.\d+).*$", _version)
+    if not matches or version.parse(matches.group(1)) < version.parse("2.7.0"):
         raise Error(_("You have an old version of git. Install version 2.7 or later, then re-run!"))
 
 
@@ -797,7 +799,7 @@ class Slug:
         else:
             cmd = f"git ls-remote --heads {self.origin}"
             try:
-                with spawn(cmd, timeout=3) as child:
+                with spawn(cmd) as child:
                     output = child.read().strip().split("\r\n")
             except pexpect.TIMEOUT:
                 if "Username for" in child.buffer:
